@@ -9,8 +9,8 @@ from m3_gar.models.reestr import (
     ReestrObjects,
 )
 from m3_gar.models.util import (
-    ParamsMixin,
     RegionCodeModelMixin,
+    add_params,
     make_fk,
 )
 
@@ -27,7 +27,7 @@ class RoomTypes(BaseRoomTypes):
         verbose_name_plural = 'Типы комнат'
 
 
-class Rooms(BaseRooms, ParamsMixin, RegionCodeModelMixin):
+class Rooms(BaseRooms, RegionCodeModelMixin):
     """
     Сведения по комнатам
     """
@@ -42,3 +42,5 @@ class Rooms(BaseRooms, ParamsMixin, RegionCodeModelMixin):
 make_fk(Rooms, 'roomtype', to=RoomTypes, null=True, blank=True)
 make_fk(Rooms, 'opertypeid', to=OperationTypes)
 make_fk(Rooms, 'objectid', to=ReestrObjects)
+
+add_params(Rooms, 'm3_gar.RoomsParams')
